@@ -348,6 +348,7 @@ __all__ = [
 
 # Shadow broken models with new definitions, and update references
 
+
 # START ChartMetadata
 class ChartMetadata(_ChartMetadata):
     # NOTE: only 'engine' has proven to be broken so far, but that makes
@@ -375,6 +376,7 @@ class Search(_Search):
 
 # END ChartMetadata
 
+
 # START Repository
 class Repository(_Repository):
     @property
@@ -452,7 +454,7 @@ class VulnerabilitySummary(_VulnerabilitySummary):
 
     @root_validator(pre=True)
     def assign_severity_breakdown(cls, values: Dict[str, Any]) -> Dict[str, Any]:
-        summary = values.get("summary", {})
+        summary = values.get("summary") or {}  # account for None
         if not isinstance(summary, dict):
             raise ValueError("'summary' must be a dict")
         return {**values, **summary}
@@ -563,6 +565,7 @@ class LdapConf(_LdapConf):
 
 # Custom models
 
+
 # /replication/adapterinfos returns a dict of RegistryProviderInfo objects,
 # where each key is the name of registry provider.
 # There is, however, no model for this in the spec.
