@@ -20,7 +20,7 @@ from harborapi.exceptions import (
     Unauthorized,
 )
 from harborapi.models import Error, Errors, UserResp
-from harborapi.utils import get_credentials
+from harborapi.utils import get_basicauth
 
 from .strategies import errors_strategy
 
@@ -46,15 +46,25 @@ def test_client_init_username():
         username="username", secret="secret", url="https://harbor.example.com/api/v2.0"
     )
     assert client.url == "https://harbor.example.com/api/v2.0"
-    assert client.credentials == get_credentials("username", "secret")
+    assert client.basicauth == get_basicauth("username", "secret")
 
 
-def test_client_init_token():
+def test_client_init_credentials():
+    with pytest.warns(DeprecationWarning):
+        client = HarborAsyncClient(
+            credentials="dXNlcm5hbWU6c2VjcmV0",
+            url="https://harbor.example.com/api/v2.0",
+        )
+    assert client.url == "https://harbor.example.com/api/v2.0"
+    assert client.basicauth == get_basicauth("username", "secret")
+
+
+def test_client_init_basicauth():
     client = HarborAsyncClient(
-        credentials="dXNlcm5hbWU6c2VjcmV0", url="https://harbor.example.com/api/v2.0"
+        basicauth="dXNlcm5hbWU6c2VjcmV0", url="https://harbor.example.com/api/v2.0"
     )
     assert client.url == "https://harbor.example.com/api/v2.0"
-    assert client.credentials == get_credentials("username", "secret")
+    assert client.basicauth == get_basicauth("username", "secret")
 
 
 def test_client_init_credentials_file(credentials_file: Path):
@@ -62,7 +72,7 @@ def test_client_init_credentials_file(credentials_file: Path):
         credentials_file=credentials_file, url="https://harbor.example.com/api/v2.0"
     )
     assert client.url == "https://harbor.example.com/api/v2.0"
-    assert client.credentials == get_credentials("robot$harborapi-test", "bad-password")
+    assert client.basicauth == get_basicauth("robot$harborapi-test", "bad-password")
 
 
 def test_client_init_no_credentials():
@@ -479,15 +489,15 @@ async def test_authentication(
         url=httpserver.url_for("/api/v2.0"),
         username=username,
         secret=secret,
-        credentials=credentials,
+        basicauth=credentials,
     )
 
     # username/password takes precedence over credentials
     if username and secret:
-        expect_credentials = get_credentials(username, secret)
+        expect_credentials = get_basicauth(username, secret).get_secret_value()
     else:
         expect_credentials = credentials
-    assert client.credentials == expect_credentials
+    assert client.basicauth.get_secret_value() == expect_credentials
 
     # Set up HTTP server to expect a certain set of headers and a method
     httpserver.expect_oneshot_request(
@@ -561,8 +571,48 @@ async def test_exceptions(
     assert exc_info.value.status_code == status_code
 
 
-async def test_log_response(async_client: HarborAsyncClient, httpserver: HTTPServer):
+async def test_response_log(async_client: HarborAsyncClient, httpserver: HTTPServer):
     """Tests handling of data from the server that does not match the schema."""
+    httpserver.expect_request("/api/v2.0/users").respond_with_json(
+        [{"username": "user1"}, {"username": "user2"}], status=200
+    )
+
+    async_client.url = httpserver.url_for("/api/v2.0")
+    await async_client.get_users()
+    await async_client.get_users()
+    await async_client.get_users()
+    assert len(async_client.response_log) == 3
+    # check default maxlen
+    assert async_client.response_log.entries.maxlen is None
+
+    # test iteration + indexing
+    for i, response in enumerate(async_client.response_log):
+        assert response == async_client.response_log[i]
+        assert response.status_code == 200
+        # ignore params in case our defaults change in the future
+        base_url = str(response.url).split("?")[0]
+        assert base_url == async_client.url + "/users"
+        assert response.method == "GET"
+        assert response.response_size > 0
+
+    # Resize log down to a smaller max size
+    oldest_response = async_client.response_log[0]
+    async_client.response_log.resize(2)
+    assert len(async_client.response_log) == 2
+    assert oldest_response not in async_client.response_log
+
+    # Resize up to a larger max size
+    async_client.response_log.resize(5)
+    assert len(async_client.response_log) == 2
+
+    # Clear the log
+    async_client.response_log.clear()
+    assert len(async_client.response_log) == 0
+    assert async_client.response_log.entries.maxlen == 5
+
+
+async def test_last_response(async_client: HarborAsyncClient, httpserver: HTTPServer):
+    """Test retrieving the last logged response."""
     httpserver.expect_oneshot_request("/api/v2.0/users").respond_with_json(
         [{"username": "user1"}, {"username": "user2"}], status=200
     )
@@ -575,6 +625,8 @@ async def test_log_response(async_client: HarborAsyncClient, httpserver: HTTPSer
     assert last_response.url == async_client.url + "/users?page=1&page_size=10"
     assert last_response.method == "GET"
     assert last_response.response_size > 0
+    async_client.response_log.clear()
+    assert async_client.last_response is None
 
 
 async def test_cookies(async_client: HarborAsyncClient, httpserver: HTTPServer):
